@@ -15,17 +15,6 @@
 
 #define OMG_LOCATOR "2809"
 
-#define NO_PROTECTION                1
-#define INTEGRITY                    2
-#define CONFIDENTIALITY              4
-#define DETECT_REPLAY                8
-#define DETECT_MISORDERING          16
-#define ESTABLISH_TRUST_IN_TARGET   32
-#define ESTABLISH_TRUST_IN_CLIENT   64
-#define NO_DELEGATION              128
-#define SIMPLE_DELEGATION          256
-#define COMPOSITE_DELEGATION       512
-
 /* does not preserve @profile string, inserts '\0' as seperator,
  * @return FALSE on failure and TRUE otherwise, on success restults
  * will be assigned to @ver and @host and @port, do not _free_
@@ -72,7 +61,7 @@ corbaloc_profile_iiop_parse (gchar  *profile,
 		++_token;
 	}
 	else {
-		_ver = ssl ? "1.1" : "1.0";
+		_ver = *ssl ? "1.1" : "1.0";
 	}
 	
 	_host = _token;
@@ -120,12 +109,8 @@ corbaloc_profile_uiop_parse (gchar           *profile,
 			     gchar          **socket_path,
 			     gushort         *ipv6_port )
 {
-	long len = 0; 
-
 	g_assert (profile && strlen (profile) > 0 );
 	
-	len = strlen (profile);
-
 	/*  [uiop]: ['//'] socket-path ':' [ port ] */ 
 
 	if (strncmp (profile, "uiop:", strlen ("uiop:"))) 
@@ -198,15 +183,15 @@ corbaloc_profile_iiop (gchar           *token,
 		
 		sslsec = g_new0 (IOP_TAG_SSL_SEC_TRANS_info, 1);     
 		sslsec->parent.component_type = IOP_TAG_SSL_SEC_TRANS;
-		sslsec->target_supports =  /* NO_PROTECTION             | */
-			                   INTEGRITY                 |
-			                   CONFIDENTIALITY           |
-                                           DETECT_REPLAY             |
-			                   DETECT_MISORDERING        |
-                                           ESTABLISH_TRUST_IN_TARGET |
-			                   ESTABLISH_TRUST_IN_CLIENT;
-		sslsec->target_requires =  INTEGRITY                 |
-			                   CONFIDENTIALITY;
+		sslsec->target_supports =  /* CSIIOP_NoProtection          | */
+			                    CSIIOP_Integrity               |
+			                   CSIIOP_Confidentiality          |
+                                           CSIIOP_DetectReplay             |
+			                   CSIIOP_DetectMisordering        |
+                                           CSIIOP_EstablishTrustInTarget   |
+			                   CSIIOP_EstablishTrustInClient;
+		sslsec->target_requires =  CSIIOP_Integrity                |
+			                   CSIIOP_Confidentiality;
 		sslsec->port = port;
 
 		iiop->components = g_slist_append (
@@ -251,7 +236,7 @@ static ORBit_ObjectKey*
 orbit_url_decode (const char * ptr)
 {
 	ORBit_ObjectKey *retval  = NULL;
-	gchar * buf = NULL; 
+	guchar * buf = NULL; 
 	
         retval = CORBA_sequence_CORBA_octet__alloc ();
 	retval->_length  = 0;
@@ -268,7 +253,7 @@ orbit_url_decode (const char * ptr)
 				CORBA_free (retval);
 				return NULL;
 			}
-			*buf = (char) (orbit_from_xdigit(ptr[1])<<4 |
+			*buf = (orbit_from_xdigit(ptr[1])<<4 |
 				       orbit_from_xdigit(ptr[2]));
 			ptr += 3;
 		}
