@@ -13,11 +13,23 @@
 
 #include "orbit-purify.h"
 
+#ifdef G_OS_WIN32
+#include <wincrypt.h>
+#endif
+
 static ORBitGenUidType  genuid_type = ORBIT_GENUID_STRONG;
+#ifndef G_OS_WIN32
 static int              random_fd = -1;
+#else
+static HCRYPTPROV	hprov = 0;
+#endif
 static GRand           *glib_prng = NULL;
 static pid_t            genuid_pid;
+#ifndef G_OS_WIN32
 static uid_t            genuid_uid;
+#else
+static int		genuid_uid = 0;
+#endif
 
 /* This is quite possibly a complete waste of cycles */
 static GMutex          *inc_lock = NULL;
@@ -39,7 +51,9 @@ ORBit_genuid_init (ORBitGenUidType type)
 	gboolean hit_strength;
 	
 	genuid_pid = getpid ();
+#ifndef G_OS_WIN32
 	genuid_uid = getuid ();
+#endif
 	inc_lock = link_mutex_new();
 
 	glib_prng = g_rand_new ();
@@ -50,13 +64,21 @@ ORBit_genuid_init (ORBitGenUidType type)
 
 	switch (genuid_type) {
 	case ORBIT_GENUID_STRONG:
+#ifndef G_OS_WIN32
 		random_fd = open ("/dev/urandom", O_RDONLY);
 
 		if (random_fd < 0)
 			random_fd = open ("/dev/random", O_RDONLY);
 
 		hit_strength = (random_fd >= 0);
-#if LINK_SSL_SUPPORT
+#else
+		if (CryptAcquireContext (&hprov, NULL, NULL, PROV_RSA_FULL,
+					 CRYPT_VERIFYCONTEXT))
+			hit_strength = TRUE;
+		else
+			hit_strength = FALSE;
+#endif
+#ifdef LINK_SSL_SUPPORT
 		hit_strength = TRUE; /* foolishly trust OpenSSL */
 #endif
 		break;
@@ -71,11 +93,17 @@ ORBit_genuid_init (ORBitGenUidType type)
 void
 ORBit_genuid_fini (void)
 {
+#ifndef G_OS_WIN32
 	if (random_fd >= 0) {
 		close (random_fd);
 		random_fd = -1;
 	}
-	
+#else
+	if (hprov) {
+		CryptReleaseContext (hprov, 0);
+		hprov = 0;
+	}
+#endif
 	if (glib_prng) {
 		g_rand_free (glib_prng);
 		glib_prng = NULL;
@@ -87,6 +115,8 @@ ORBit_genuid_fini (void)
 	}
 }
 
+#ifndef G_OS_WIN32
+
 static gboolean
 genuid_rand_device (guchar *buffer, int length)
 {
@@ -113,7 +143,9 @@ genuid_rand_device (guchar *buffer, int length)
 	return TRUE;
 }
 
-#if LINK_SSL_SUPPORT
+#endif
+
+#ifdef LINK_SSL_SUPPORT
 #include <openssl/rand.h>
 
 static gboolean
@@ -207,9 +239,15 @@ ORBit_genuid_buffer (guint8         *buffer,
 	switch (type) {
 
 	case ORBIT_GENUID_STRONG:
+#ifndef G_OS_WIN32
 		if (random_fd >= 0 &&
 		    genuid_rand_device (buffer, length))
 			return;
+#else
+		if (hprov &&
+		    CryptGenRandom (hprov, length, buffer))
+			return;
+#endif
 #if LINK_SSL_SUPPORT
 		else if (genuid_rand_openssl (buffer, length))
 			return;
@@ -222,7 +260,7 @@ ORBit_genuid_buffer (guint8         *buffer,
 		break;
 
 	default:
-		g_error ("serious randomnes failure");
+		g_error ("serious randomness failure");
 		break;
 	}
 }
